@@ -1,3 +1,4 @@
+import re
 from django.conf import settings
 from django.core.paginator import Paginator, EmptyPage
 
@@ -42,3 +43,17 @@ def check_allow_for_user(start_user, end_user):
         return True
 
     return False
+
+
+def check_allow_for_uri(uri):
+    uri = uri.lstrip('/')
+
+    exclusions = getattr(settings, 'IMPERSONATE_URI_EXCLUSIONS', (r'^admin/',))
+    if not isinstance(exclusions, (list, tuple)):
+        exclusions = (exclusions,)
+
+    for exclusion in exclusions:
+        if re.search(exclusion, uri):
+            return False
+
+    return True
